# Datahugger - Where DOI 👐 Data

Datahugger is a tool to download scientific datasets, software, and code from
a large number of repositories based on their DOI [(wiki)](https://en.wikipedia.org/wiki/Digital_object_identifier) or URL. With
Datahugger, you can automate the downloading of data and improve the
reproducibility of your research. Datahugger provides a straightforward
[Python interface](#download-with-python) as well as an intuitive
[Command Line Interface](#download-with-command-line) (CLI).

<p align="center">
  <img alt="Datahugger - Where DOI hugs data" src="images/datahugger_repo.svg">
</p>

## Alternatives

Datahugger's main focus is on downloading datasets from arbitrary DOI's. As
far as I know, there are no alternatives for downloading datasets from arbitrary
DOI's. However, there are many libraries for downloading datasets from a
repository right away. Usually they can also be used for uploading data to
the repository. Nice examples are:

- [https://guides.dataverse.org/en/latest/api/client-libraries.html](https://guides.dataverse.org/en/latest/api/client-libraries.html)
- [https://pypi.org/project/pyzenodo3/](https://pypi.org/project/pyzenodo3/)
- [https://osfclient.readthedocs.io/en/latest/](https://osfclient.readthedocs.io/en/latest/)
